atomate.lammps package — atomate 0.9.2 documentation

# atomate.lammps package

## Subpackages

- atomate.lammps.firetasks package
  - Submodules
  - atomate.lammps.firetasks.glue_tasks module
  - atomate.lammps.firetasks.parse_outputs module
  - atomate.lammps.firetasks.run_calc module
  - atomate.lammps.firetasks.write_inputs module
  - Module contents
- atomate.lammps.fireworks package
  - Submodules
  - atomate.lammps.fireworks.core module
  - Module contents
- atomate.lammps.workflows package
  - Submodules
  - atomate.lammps.workflows.core module
  - Module contents

## Submodules

## atomate.lammps.database module

class `atomate.lammps.database.` `LammpsCalcDb`(host='localhost', port=27017, database='lammps', collection='tasks', user=None, password=None, **kwargs)

  Bases: `atomate.utils.database.CalcDb`

  `__init__`(host='localhost', port=27017, database='lammps', collection='tasks', user=None, password=None, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  `build_indexes`(indexes=None, background=True)

    Build the indexes.

    Args:

      indexes (list): list of single field indexes to be built. background (bool): Run in the background or not.

  `reset`()

## atomate.lammps.drones module

class `atomate.lammps.drones.` `LammpsDrone`(additional_fields=None, use_full_uri=True, diffusion_params=None)

  Bases: `pymatgen.apps.borg.hive.AbstractDrone`

  `__init__`(additional_fields=None, use_full_uri=True, diffusion_params=None)
    Args:

      additional_fields (dict): use_full_uri (bool): diffusion_params (dict): parameters to the diffusion_analyzer. If specified a summary

      > of diffusion statistics will be added.

  `as_dict`()

    A JSON serializable dict representation of an object.

  `assimilate`(path, input_filename, log_filename='log.lammps', is_forcefield=False, data_filename=None, dump_files=None)

    Parses lammps input, data and log files and insert the result into the db.

    Args:

      path (str): path to the run folder input_filename (str): just the name of the input file log_filename (str): lammps log file name is_forcefield (bool): whether or not ot parse forcefield info data_filename (str): name of the data file dump_files ([str]): list of dump file names

    Returns:

      dict

  classmethod `from_dict`(d)
  `generate_doc`(dir_name, lmps_input, log, dumps)
    Args:

      dir_name (str): path to the run dir. lmps_input (LammpsInput/LammpsInputSet): log (LammpsLog): dumps ([(filename, LammpsDump)]): list of (dump filename, dump) tuples

    Returns:

      dict

  `get_valid_paths`(path)

    Checks if path contains valid data for assimilation, and then returns the valid paths. The paths returned can be a list of directory or file paths, depending on what kind of data you are assimilating. For example, if you are assimilating VASP runs, you are only interested in directories containing vasprun.xml files. On the other hand, if you are interested converting all POSCARs in a directory tree to cifs for example, you will want the file paths.

    Args:
      path: input path as a tuple generated from os.walk, i.e.,

        (parent, subdirs, files).

    Returns:

      List of valid dir/file paths for assimilation

  `post_process`(d, lmps_run)

    Simple post processing.

    Args:

      d (dict) lmps_run (LammpsRun)

  `schema` = {'root': {'completed_at', 'dir_name', 'input', 'last_updated', 'output', 'schema', 'state'}}

## atomate.lammps.utils module

`atomate.lammps.utils.` `use_fake_lammps`(original_wf, ref_dir)

## Module contents